{% load static %}

<!DOCTYPE html>
<html lang="en" class="no-js">
    <head prefix='og: http://ogp.me/ns#'>
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <title>{{ budget_name }}</title>

        <link rel="shortcut icon" type="image/x-icon" href="/img/favicon-premium.ico" />

        <!-- <link href='https://fonts.googleapis.com/css?family=Roboto:400,500,700,900,400italic,700italic,500italic' rel='stylesheet' type='text/css'> -->

        <link href="{% static 'budget/css/budget.css' %}" rel="stylesheet" type="text/css" />
        <link href="{% static 'budget/css/branding.css' %}" rel="stylesheet" type="text/css" />
    </head>

    <body>
        <script type="text/javascript">
            var adminEmail = 'ajvestal@dallasnews.com';

            var externalURLs = {};
            externalURLs.addVisualsRequest = null;
        </script>
        <script src="{% static 'budget/js/main-budget.js' %}"></script>

        <script type="text/javascript">
          budget.initialize({
            configURL: '{{ config_url }}'
          });
        </script>
    </body>
</html>
