# -*- coding: utf-8 -*-
# Generated by Django 1.10b1 on 2016-06-28 22:19
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0019_auto_20160628_1251'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='package',
            name='serialized_object',
        ),
    ]
