@import url('https://fonts.googleapis.com/icon?family=Material+Icons');

@import "_variables";

// @import 'foundation_settings';
// @import 'foundation';

// @include foundation-global-styles;
// @include foundation-grid;
// @include foundation-typography;
// @include foundation-forms;
// @include foundation-button;
// @include foundation-accordion;
// @include foundation-accordion-menu;
// @include foundation-badge;
// @include foundation-breadcrumbs;
// @include foundation-button-group;
// @include foundation-callout;
// @include foundation-close-button;
// @include foundation-menu;
// @include foundation-menu-icon;
// @include foundation-drilldown-menu;
// @include foundation-dropdown;
// @include foundation-dropdown-menu;
// @include foundation-flex-video;
// @include foundation-label;
// @include foundation-media-object;
// @include foundation-off-canvas;
// @include foundation-orbit;
// @include foundation-pagination;
// @include foundation-progress-bar;
// @include foundation-slider;
// @include foundation-sticky;
// @include foundation-reveal;
// @include foundation-switch;
// @include foundation-table;
// @include foundation-tabs;
// @include foundation-thumbnail;
// @include foundation-title-bar;
// @include foundation-tooltip;
// @include foundation-top-bar;
// @include foundation-visibility-classes;
// @include foundation-float-classes;



// @import "fonts";

// Bootstrap
// @import "bootstrap-custom";

// Longbill-Daterangepicker
// @import "../../vendored/longbill-daterangepicker/daterangepicker";

// Air-Datepicker
@import "../../node_modules/daterange-picker-ex/src/daterangepicker";

// Time picker
@import "../../node_modules/timedropper-ex/src/timedropper";

// Quill.js
@import "../../node_modules/quill/dist/quill.base";
// @import "../../node_modules/quill/dist/quill.snow";

// Selectize.js
@import "../../node_modules/selectize/dist/css/selectize";
// @import "../../node_modules/selectize/dist/css/selectize.bootstrap3";

// Vex.js
@import "../../node_modules/vex-scss/src/scss/vex";
@import "../../node_modules/vex-scss/src/scss/vex-theme-plain";
@import "../../node_modules/vex-scss/src/scss/_keyframes";
@import "../../node_modules/vex-scss/src/scss/_mixins";

// @import "mixins";

// App styles
// @import "blog";
// @import "upshot";
// @import "navbar";
@import "buttons";
// @import "page-header";
@import "_data_tables";
@import "_grid";
@import "_layout";
@import "_filters";
@import "_filters_print_view";
@import "_modal_keyframes";
@import "_modals";
@import "_packages";
@import "_package_editing";
@import "_quill_theme";
@import "_snackbar";
@import "_typography";

@import "_print";

// @import "ads";
// @import "quiz";
// @import "progress-bars";
// @import "results";
// @import "forms";
// @import "type";
// @import "pres-results";
// @import "unit-chart";
// @import "share-tray";
// @import "overrides";
