# -*- coding: utf-8 -*-
# Generated by Django 1.10rc1 on 2016-08-11 05:32
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0021_auto_20160630_1736'),
    ]

    operations = [
        migrations.AddField(
            model_name='package',
            name='print_system_slug',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
    ]
