# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-04-20 23:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0002_auto_20160328_1347'),
    ]

    operations = [
        migrations.AddField(
            model_name='item',
            name='slug_key',
            field=models.CharField(default='article', max_length=20),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='item',
            name='slug',
            field=models.CharField(db_index=True, max_length=100, unique=True),
        ),
    ]
